#
# spec file for package ltp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ltp
Version:        20190115
Release:        1.1
Summary:        The Linux Test Project
License:        GPL-2.0+
Group:          System/Benchmark
URL:            http://linux-test-project.github.io
Source:         https://github.com/linux-test-project/ltp/releases/download/%{version}/ltp-full-%{version}.tar.xz
Source99:       baselibs.conf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libacl-devel
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libcap-devel
BuildRequires:  libnuma-devel
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  pkgconfig
BuildRequires:  xfsprogs-devel
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(uuid)
Recommends:     acl
Recommends:     net-tools
Recommends:     numactl
Recommends:     psmisc
Recommends:     quota
Recommends:     rpmbuild
Recommends:     sudo
Recommends:     sysstat
Recommends:     tpm-tools
Recommends:     wget
Conflicts:      otherproviders(ltp)
%{perl_requires}

%description
A collection of test suites to validate the reliability, robustness and
stability of Linux. It provides tools for testing the kernel and
related features.

%prep
%setup -q -n ltp-full-%{version}

%build
%configure \
  --prefix=/opt/ltp \
  --with-realtime-testsuite \
  --with-open-posix-testsuite
make all %{?_smp_mflags}

%install
%make_install

# Deal with openposix test binaries and create runtest file
mkdir -p %{buildroot}/opt/ltp/testcases/bin/openposix

cd testcases/open_posix_testsuite
# Exclude tests which are "build only"
for i in `find conformance/interfaces/ -name '*.run-test' -a ! -name '*-buildonly*'` ; do
	# create runtest openposix file
	echo `basename "$i" .run-test | sed s/-/_/` '${LTPROOT}/testcases/bin/openposix/'$i >> ../../runtest/openposix;
	# install binaries
	mkdir -p %{buildroot}/opt/ltp/testcases/bin/openposix/`dirname $i`;
	cp $i %{buildroot}/opt/ltp/testcases/bin/openposix/`dirname $i`;
done
cp ../../runtest/openposix %{buildroot}/opt/ltp/runtest/
cd ../..

# Exclude tst_brkm
HARDLINKS1="tst_exit tst_flush tst_fs_has_free tst_get_unused_port tst_kvercmp tst_brk"
HARDLINKS2="tst_res tst_kvercmp2 tst_ncpus tst_ncpus_conf tst_ncpus_max tst_resm"
cd %{buildroot}/opt/ltp/testcases/bin
for n in $HARDLINKS1 $HARDLINKS2; do
	ln -s -f tst_brkm $n
done

%files
%doc README.md INSTALL COPYING
/opt/ltp/
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_bindir}/execltp
%{_bindir}/ffsb

%changelog
* Fri Feb 22 2019 petr@cervinka.net
- Update to version 20190115
- Add rpmlintrc
- New tests
  * fanotify11 - test for FAN_REPORT_TID
  * fanotify01, fanotify03, fanotify10
  * added coverage for FAN_MARK_FILESYSTEM
  * fanotify03
  * added coverage for mountpoint mark
  * getrlimit03 - test if getrlimit syscalls return consistent data
  * increased coverage for readahead and posix_fadvise on overlayfs
  * execveat01 - functional tests
  * execveat02 - invalid inputs tests
  * statx06 - checks for correct statx timestamps
  * lremovexattr01 - functional tests
  * fremovexattr01 - functional tests
  * fremovexattr02 - invalid inputs tests
  * pt_test - Intel PT full trace test
  * membarier01 - functional tests
  * preadv201 - functional tests
  * preadv202 - invalid inputs tests
  * new open posix conformance tests for strchr, strcpy, strncpy,
- New regression tests
  * crypto_user01 aka CVE-2018-19854 (previously known as CVE-2013-2547)
  * fanout01 aka CVE-2017-15649
  * fanotify09
  * added coverage for merging events on child subdir
  * fixed in b469e7e47c8a "fanotify: fix handling of events on child sub-directory"
  * fanotify10 - test for mount ignore mask
  * fixed in 9bdda4e9cf2d fsnotify: fix ignore mask logic in fsnotify()
  * getxattr05
  * fixed in 82c9a927bc5d ("getxattr: use correct xattr length")
- Additional 37 tests were converted to the new test library; with that about
  30%% of the LTP syscall testcases have been converted so far
- The fzsync library intended to trigger kernel races has been rewritten again,
  the code is simpler now and at the same time the probability to hit races
  has increased.
* Fri Oct 27 2017 mpluskal@suse.com
- Update to version 20170929
* Sun Jul 16 2017 mpluskal@suse.com
- Update to version 20170516
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 20170116
* Tue Sep 20 2016 mpluskal@suse.com
- Update to version 20160920
* Fri Sep  2 2016 mpluskal@suse.com
- Add baselibs.conf
* Wed May 11 2016 mpluskal@suse.com
- Update to version 20160126
* Fri Mar 18 2016 mpluskal@suse.com
- Initial package for version 20160126
